/* User Interface Utilities
 * Copyright (C) 1999 - Jeff Heflin - University of Maryland
 *
 * This source code may be redistributed or modified provided that
 * this notice is unchanged and all modifications are clearly indicated.
 * No portion of this code may be included in a commercial product without
 * the written permission of the author.
 *
 * The software and related materials are provided "as-is" without
 * warranty or indemnity of any kind, including any warranties of
 * use, performance or merchantability or fitness for a particular use
 * or purpose or for any purpose whatsoever. User bears all risk
 * relating to use, quality and performance of the software.
 *
 * Author: Jeff Heflin
 * e-mail: heflin@cs.umd.edu
 *
 */

package UserInt;

import java.awt.*;

/** A collection of static methods to perform useful functions including
   methods that ease the use of the GridBagLayout manager, a method to
   add a component that consists of a label and a text field to a
   GridBagLayout, and a method to work around the problems with dialog
   windows in different versions and implementations of Java. */
public class Utilities {

  /* If scrolls is true, the item is assumed to have possible scrollbars,
     and insets are added to the bottom and right to accomodate this bar. */
  public static void placeComponent(Container container, Component component,
				    int x, int y, int width, int height,
				    int anchor, double weightx,
				    double weighty, boolean insets) {

    GridBagLayout gridbag = null;
    try {
      gridbag = (GridBagLayout)(container.getLayout());
    } catch (Exception e) {
      System.err.println("Hey!  You called placeComponent with"
			 + " a container that doesn't "
			 + " use GridBagLayout!");
      return;
    }

    GridBagConstraints c = new GridBagConstraints();

    c.gridx = x;
    c.gridy = y;
    c.gridwidth = width;
    c.gridheight = height;
    c.anchor = anchor;
    c.weightx = weightx;
    c.weighty = weighty;
    // c.fill = GridBagConstraints.HORIZONTAL;
    c.fill = GridBagConstraints.BOTH;
    if (insets == true)
      c.insets = new Insets(0, 0, 10, 15);
    gridbag.setConstraints(component, c);
    container.add(component);
  }

  public static void placeComponent(Container container, Component component,
				    int x, int y, int width, int height) {
    /* place a component using only position and size */

    placeComponent(container, component, x, y, width, height,
		   GridBagConstraints.CENTER, 0.0, 0.0, false);
  }

  public static void placeComponent(Container container, Component component,
				    int x, int y, int width, int height,
				    boolean insets) {
    /* place a component using position, size, and insets */
    
    placeComponent(container, component, x, y, width, height,
		   GridBagConstraints.CENTER, 0.0, 0.0, insets);
  }

  public static void placeComponent(Container container, Component component,
				    int x, int y, int width, int height,
				    double weightx, double weighty) {
    /* place a component using position, size, and degree of fill */
    
    placeComponent(container, component, x, y, width, height,
		   GridBagConstraints.CENTER, weightx, weighty, false);
  }

  public static void placeComponent(Container container, Component component,
				    int x, int y, int width, int height,
				    double weightx, double weighty,
				    boolean insets) {
    /* place a component using position, size, degree of fill and insets */
    
    placeComponent(container, component, x, y, width, height,
		   GridBagConstraints.CENTER, weightx, weighty, insets);
  }

  public static void placeComponent(Container container, Component component,
				    int x, int y, int width, int height,
				    int anchor) {
    /* place a component using position, size and alignment */

    placeComponent(container, component, x, y, width, height,
		   anchor, 0.0, 0.0, false);
  }


    
  /**
   * Add a label-value pair to a container that uses
   * GridBagLayout.
   */
  public static void addParameterRow(Container container,
				     Label label,
				     Component component) {
    GridBagLayout gridbag = null;
    try {
      gridbag = (GridBagLayout)(container.getLayout());
    } catch (Exception e) {
      System.err.println("Hey!  You called addRow with"
			 + " a container that doesn't "
			 + " use GridBagLayout!");
      return;
    }
    
    GridBagConstraints c = new GridBagConstraints();
    c.fill = GridBagConstraints.HORIZONTAL;
    //c.weighty = 1.0;
    c.insets = new Insets(0, 5, 0, 5);
    
    gridbag.setConstraints(label, c);
    container.add(label);
    c.gridwidth = GridBagConstraints.REMAINDER;
    c.weightx = 1.0;
    gridbag.setConstraints(component, c);
    container.add(component);
  }

}
